@@ -1,6 +1,6 @@
-### This file defines the generics which make up the interface formatters offers.
+### This file defines the generics which make up the interface `formatters` offers.
 ### Defining methods for these generics for a new table-like class should be fully
-### sufficient for hooking that class up to the formatters pagination and rendering
+### sufficient for hooking that class up to the `formatters` pagination and rendering
 ### machinery.
 
 
@@ -45,7 +45,7 @@
 #' `make_row_df` methods can call `make_row_df` recursively and retain information,
 #' and should not be set during a top-level call
 #'
-#' @note the technically present root tree node is excluded from the summary returned dby
+#' @note the technically present root tree node is excluded from the summary returned by
 #' both \code{make_row_df} and \code{make_col_df}, as it is simply the
 #' row/column structure of \code{tt} and thus not useful for pathing or pagination.
 #' @export
@@ -68,12 +68,12 @@ setGeneric("make_row_df", function(tt, colwidths = NULL, visible_only = TRUE,
 ## nocov end
 
 
-#' Transform rtable to a list of matrices which can be used for outputting
+#' Transform `rtable` to a list of matrices which can be used for outputting
 #'
-#' Although rtables are represented as a tree data structure when outputting the table to ASCII or HTML it is useful to
-#' map the rtable to an in between state with the formatted cells in a matrix form.
+#' Although `rtables` are represented as a tree data structure when outputting the table to ASCII or HTML it is useful to
+#' map the `rtable` to an in between state with the formatted cells in a matrix form.
 #'
-#' @param obj ANY. Object to be transformed into a ready-to-render form (a MatrixPrintForm object)
+#' @param obj ANY. Object to be transformed into a ready-to-render form (a `MatrixPrintForm` object)
 #' @param indent_rownames logical(1), if TRUE the column with the row names in the `strings` matrix of has indented row
 #' names (strings pre-fixed)
 #' @param expand_newlines logical(1). Should the matrix form generated
@@ -119,10 +119,10 @@ setMethod("matrix_form", "MatrixPrintForm", function(obj,
 })
 
 
-## Generics for toString and helper functions
+## Generics for `toString` and helper functions
 
 
-## this is where we will take wordwrapping
+## this is where we will take word wrapping
 ## into account when it is added
 ##
 ## ALL calculations of vertical space for pagination
@@ -203,7 +203,7 @@ setMethod("nlines", "character", function(x, colwidths, max_width) {
 
 
 
-#' @title toString
+#' @title `toString`
 #'
 #' @description Transform a complex object into a string representation ready
 #' to be printed or written to a plain-text file
@@ -233,17 +233,17 @@ setMethod("print", "ANY", base::print) ## nocov
 
 
 
-## General/"universal" property getter and setter generics and stubs
+## General/"universal" property `getter` and `setter` generics and stubs
 
 #' @title Label, Name and Format accessor generics
 #'
-#' @description Getters and setters for basic, relatively universal attributes
+#' @description `Getters` and `setters` for basic, relatively universal attributes
 #' of "table-like" objects"
 #'
 #' @name lab_name
 #' @param obj ANY. The object.
 #' @param value character(1)/FormatSpec. The new value of the attribute.
-#' @return the name, format or label of \code{obj} for getters, or \code{obj} after modification
+#' @return the name, format or label of \code{obj} for `getters`, or \code{obj} after modification
 #' for setters.
 #' @aliases obj_name
 #' @export
@@ -289,7 +289,9 @@ setGeneric("obj_format", function(obj) standardGeneric("obj_format"))
 #' @rdname lab_name
 #' @exportMethod obj_format
 setMethod("obj_format", "ANY", function(obj) attr(obj, "format", exact = TRUE))
-
+#' @rdname lab_name
+#' @export
+setMethod("obj_format", "fmt_config", function(obj) obj@format)
 
 #' @export
 #' @rdname lab_name
@@ -301,6 +303,12 @@ setMethod("obj_format<-", "ANY", function(obj, value) {
   attr(obj, "format") <- value
   obj
 })
+#' @rdname lab_name
+#' @export
+setMethod("obj_format<-", "fmt_config", function(obj, value) {
+  obj@format <- value
+  obj
+})
 
 #' @rdname lab_name
 #' @export
@@ -308,6 +316,10 @@ setGeneric("obj_na_str", function(obj) standardGeneric("obj_na_str"))
 #' @rdname lab_name
 #' @exportMethod obj_na_str
 setMethod("obj_na_str", "ANY", function(obj) attr(obj, "format_na_str", exact = TRUE))
+#' @rdname lab_name
+#' @export
+setMethod("obj_na_str", "fmt_config", function(obj) obj@format_na_str)
+
 #' @rdname lab_name
 #' @export
 setGeneric("obj_na_str<-", function(obj, value) standardGeneric("obj_na_str<-"))
@@ -317,14 +329,45 @@ setMethod("obj_na_str<-", "ANY", function(obj, value) {
   attr(obj, "format_na_str") <- value
   obj
 })
+#' @rdname lab_name
+#' @export
+setMethod("obj_na_str<-", "fmt_config", function(obj, value) {
+  obj@format_na_str <- value
+  obj
+})
 
+#' @rdname lab_name
+#' @export
+setGeneric("obj_align", function(obj) standardGeneric("obj_align"))
+#' @rdname lab_name
+#' @exportMethod obj_align
+setMethod("obj_align", "ANY", function(obj) attr(obj, "align", exact = TRUE))
+#' @rdname lab_name
+#' @export
+setMethod("obj_align", "fmt_config", function(obj) obj@align)
+
+#' @rdname lab_name
+#' @export
+setGeneric("obj_align<-", function(obj, value) standardGeneric("obj_align<-"))
+#' @exportMethod obj_align<-
+#' @rdname lab_name
+setMethod("obj_align<-", "ANY", function(obj, value) {
+  attr(obj, "align") <- value
+  obj
+})
+#' @rdname lab_name
+#' @export
+setMethod("obj_align<-", "fmt_config", function(obj, value) {
+  obj@align <- value
+  obj
+})
 
 #' General title/footer accessors
 #'
 #' @param obj ANY. Object to extract information from.
 #' @export
 #' @rdname title_footer
-#' @return a character scalar (`main_title`, `main_footer`), or
+#' @return A character scalar (`main_title`), a character vector (`main_footer`), or
 #' vector of length zero or more (`subtitles`, `page_titles`,
 #' `prov_footer`) containing the relevant title/footer contents
 setGeneric("main_title", function(obj) standardGeneric("main_title"))
