@@ -150,12 +150,12 @@ test_that("row label wrapping has identical indentation", {
   mf_rinfo(matform)$indent <- c(1, 2)
   matform$strings[2, 1] <- paste0(" ", matform$strings[2, 1]) # Does not respect indent_size
   matform$strings[3, 1] <- paste0("  ", matform$strings[3, 1]) # Does not respect indent_size
-  catform <- toString(matform, widths = c(15, 5)) # This reindent (correctly) the rows
+  catform <- toString(matform, widths = c(15, 5), hsep = "-") # This reindent (correctly) the rows
   res_vec <- strsplit(catform, "\n")[[1]]
   exp_vec <- c(
     "                   all_o",
     "                    bs  ",
-    " ———————————————————————",
+    " -----------------------",
     "   Something to    3    ",
     "   wrap                 ",
     "     Also here     4    ",
